InverseGeometricMeanRank
========================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: InverseGeometricMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InverseGeometricMeanRank.increasing
      ~InverseGeometricMeanRank.name
      ~InverseGeometricMeanRank.synonyms
      ~InverseGeometricMeanRank.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~InverseGeometricMeanRank.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
